define(
//begin v1.x content
({
	"saveLabel": "Opslaan",
	"saveSettingLabelOn": "Interval voor automatisch opslaan instellen...",
	"saveSettingLabelOff": "Automatisch opslaan uitschakelen",
	"saveSettingdialogTitle": "Automatisch opslaan",
	"saveSettingdialogDescription": "Geef het interval voor Automatisch opslaan op.",
	"saveSettingdialogParamName": "Interval voor Automatisch opslaan",
	"saveSettingdialogParamLabel": "min",
	"saveSettingdialogButtonOk": "Interval instellen",
	"saveSettingdialogButtonCancel": "Annuleren",
	"saveMessageSuccess": "Opgeslagen op ${0}",
	"saveMessageFail": "Opslaan mislukt op ${0}"
})

//end v1.x content
);
